Crate kcr_config_storageos_com

Crate kcr_config_storageos_com 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the config.storageos.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

config.storageos.com/v1

  • OperatorConfig

Modules

v1